@@ -490,6 +490,7 @@ impl<'src> Lexer<'src> {
       '@' => self.lex_single(At),
       '[' => self.lex_delimiter(BracketL),
       '\n' | '\r' => self.lex_eol(),
+      '\u{feff}' => self.lex_single(ByteOrderMark),
       ']' => self.lex_delimiter(BracketR),
       '`' | '"' | '\'' => self.lex_string(),
       '{' => self.lex_delimiter(BraceL),
@@ -926,6 +927,7 @@ mod tests {
       BraceR => "}",
       BracketL => "[",
       BracketR => "]",
+      ByteOrderMark => "\u{feff}",
       Colon => ":",
       ColonEquals => ":=",
       Comma => ",",
