@@ -76,8 +76,8 @@ impl Subcommand {
       Command { overrides, .. } | Evaluate { overrides, .. } => {
         justfile.run(config, &search, overrides, &[])?
       }
-      Dump => Self::dump(ast),
-      Format => Self::format(config, ast, &search)?,
+      Dump => Self::dump(config, ast, justfile)?,
+      Format => Self::format(config, &search, &src, ast)?,
       List => Self::list(config, justfile),
       Run {
         arguments,
@@ -229,8 +229,17 @@ impl Subcommand {
     Ok(())
   }
 
-  fn dump(ast: Ast) {
-    print!("{}", ast);
+  fn dump(config: &Config, ast: Ast, justfile: Justfile) -> Result<(), Error<'static>> {
+    match config.dump_format {
+      DumpFormat::Json => {
+        config.require_unstable("The JSON dump format is currently unstable.")?;
+        serde_json::to_writer(io::stdout(), &justfile)
+          .map_err(|serde_json_error| Error::DumpJson { serde_json_error })?;
+        println!();
+      }
+      DumpFormat::Just => print!("{}", ast),
+    }
+    Ok(())
   }
 
   fn edit(search: &Search) -> Result<(), Error<'static>> {
@@ -255,22 +264,47 @@ impl Subcommand {
     Ok(())
   }
 
-  fn format(config: &Config, ast: Ast, search: &Search) -> Result<(), Error<'static>> {
+  fn format(config: &Config, search: &Search, src: &str, ast: Ast) -> Result<(), Error<'static>> {
     config.require_unstable("The `--fmt` command is currently unstable.")?;
 
-    if let Err(io_error) =
-      File::create(&search.justfile).and_then(|mut file| write!(file, "{}", ast))
-    {
-      Err(Error::WriteJustfile {
-        justfile: search.justfile.clone(),
-        io_error,
-      })
-    } else {
-      if config.verbosity.loud() {
-        eprintln!("Wrote justfile to `{}`", search.justfile.display());
-      }
-      Ok(())
+    let formatted = ast.to_string();
+
+    if config.check {
+      return if formatted != src {
+        use similar::{ChangeTag, TextDiff};
+
+        let diff = TextDiff::configure()
+          .algorithm(similar::Algorithm::Patience)
+          .diff_lines(src, &formatted);
+
+        for op in diff.ops() {
+          for change in diff.iter_changes(op) {
+            let (symbol, color) = match change.tag() {
+              ChangeTag::Delete => ("-", config.color.stderr().diff_deleted()),
+              ChangeTag::Equal => (" ", config.color.stderr()),
+              ChangeTag::Insert => ("+", config.color.stderr().diff_added()),
+            };
+
+            eprint!("{}{}{}{}", color.prefix(), symbol, change, color.suffix());
+          }
+        }
+
+        Err(Error::FormatCheckFoundDiff)
+      } else {
+        Ok(())
+      };
     }
+
+    fs::write(&search.justfile, formatted).map_err(|io_error| Error::WriteJustfile {
+      justfile: search.justfile.clone(),
+      io_error,
+    })?;
+
+    if config.verbosity.loud() {
+      eprintln!("Wrote justfile to `{}`", search.justfile.display());
+    }
+
+    Ok(())
   }
 
   fn init(config: &Config) -> Result<(), Error<'static>> {
